@@ -234,7 +234,7 @@ class TrocketClient(AbstractClient):
 
 
     def DeleteInstance(self, request):
-        """删除实例
+        """删除 RocketMQ 5.x 集群。
 
         :param request: Request instance for DeleteInstance.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DeleteInstanceRequest`
@@ -394,6 +394,29 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeConsumerClient(self, request):
+        """查询消费者客户端详情
+
+        :param request: Request instance for DescribeConsumerClient.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeConsumerClientRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeConsumerClientResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeConsumerClient", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeConsumerClientResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeConsumerGroup(self, request):
         """查询消费组详情
 
@@ -443,8 +466,59 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeConsumerLag(self, request):
+        """查询指定消费组堆积数。
+
+        :param request: Request instance for DescribeConsumerLag.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeConsumerLagRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeConsumerLagResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeConsumerLag", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeConsumerLagResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeFusionInstanceList(self, request):
+        """查询集群列表，支持 4.x 和 5.x 集群，其中 Filters 参数使用说明如下：
+        1. InstanceName, 名称模糊查询
+        2. InstanceId，集群ID查询
+        3. InstanceType, 集群类型查询，支持多选
+        4. Version，集群版本查询
+        当使用TagFilters查询时，Filters参数失效。
+
+        :param request: Request instance for DescribeFusionInstanceList.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeFusionInstanceListRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeFusionInstanceListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeFusionInstanceList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeFusionInstanceListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeInstance(self, request):
-        """查询实例信息
+        """查询 RocketMQ 5.x 集群信息。
 
         :param request: Request instance for DescribeInstance.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeInstanceRequest`
@@ -467,11 +541,11 @@ class TrocketClient(AbstractClient):
 
 
     def DescribeInstanceList(self, request):
-        """获取实例列表，Filters参数使用说明如下：
+        """查询集群列表，仅支持 5.x 集群。Filters参数使用说明如下：
         1. InstanceName, 名称模糊查询
-        2. InstanceId，实例ID查询
-        3. InstanceType, 实例类型查询，支持多选
-        3. InstanceStatus，实例状态查询，支持多选
+        2. InstanceId，集群ID查询
+        3. InstanceType, 集群类型查询，支持多选
+        3. InstanceStatus，集群状态查询，支持多选
 
         当使用TagFilters查询时，Filters参数失效。
 
@@ -782,6 +856,98 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeMessage(self, request):
+        """查询消息详情
+
+        :param request: Request instance for DescribeMessage.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeMessageRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeMessageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeMessage", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeMessageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeMessageList(self, request):
+        """查询消息列表。如果查询死信消息，请设置ConsumerGroup参数。
+
+        :param request: Request instance for DescribeMessageList.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeMessageListRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeMessageListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeMessageList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeMessageListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeMessageTrace(self, request):
+        """根据消息 ID 查询消息轨迹。
+
+        :param request: Request instance for DescribeMessageTrace.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeMessageTraceRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeMessageTraceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeMessageTrace", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeMessageTraceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeProductSKUs(self, request):
+        """查询产品售卖规格，针对 RocketMQ 5.x 集群。
+
+        :param request: Request instance for DescribeProductSKUs.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeProductSKUsRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeProductSKUsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeProductSKUs", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeProductSKUsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeRoleList(self, request):
         """查询角色列表，Filter参数使用说明如下：
 
@@ -858,6 +1024,31 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeTopicListByGroup(self, request):
+        """根据消费组获取主题列表，Filter参数使用说明如下：
+
+        TopicName，主题名称过滤
+
+        :param request: Request instance for DescribeTopicListByGroup.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeTopicListByGroupRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeTopicListByGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTopicListByGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTopicListByGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ImportSourceClusterConsumerGroups(self, request):
         """导入消费者组列表
 
@@ -928,7 +1119,7 @@ class TrocketClient(AbstractClient):
 
 
     def ModifyInstance(self, request):
-        """修改实例属性
+        """修改 RocketMQ 5.x 集群属性。
 
         :param request: Request instance for ModifyInstance.
         :type request: :class:`tencentcloud.trocket.v20230308.models.ModifyInstanceRequest`
@@ -950,6 +1141,29 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyInstanceEndpoint(self, request):
+        """修改 RocketMQ 5.x 集群接入点。
+
+        :param request: Request instance for ModifyInstanceEndpoint.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.ModifyInstanceEndpointRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.ModifyInstanceEndpointResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstanceEndpoint", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstanceEndpointResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyMQTTInsPublicEndpoint(self, request):
         """更新MQTT实例公网接入点
 
@@ -1105,6 +1319,29 @@ class TrocketClient(AbstractClient):
             model = models.ModifyTopicResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ResendDeadLetterMessage(self, request):
+        """重新发送死信消息
+
+        :param request: Request instance for ResendDeadLetterMessage.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.ResendDeadLetterMessageRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.ResendDeadLetterMessageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ResendDeadLetterMessage", params, headers=headers)
+            response = json.loads(body)
+            model = models.ResendDeadLetterMessageResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
